summaryrefslogtreecommitdiffstats
path: root/chrome/common
diff options
context:
space:
mode:
authorbrg@chromium.com <brg@chromium.com@0039d316-1c4b-4281-b951-d872f2087c98>2009-09-29 09:11:44 +0000
committerbrg@chromium.com <brg@chromium.com@0039d316-1c4b-4281-b951-d872f2087c98>2009-09-29 09:11:44 +0000
commit345a8b7973e6693d115d20573f7cef17e4525cb3 (patch)
tree2a77dcf7842d660688a9775569f1adee43a82184 /chrome/common
parent2c365900efc2d9aeba3df9c7f5afd1e45d9b530d (diff)
downloadchromium_src-345a8b7973e6693d115d20573f7cef17e4525cb3.zip
chromium_src-345a8b7973e6693d115d20573f7cef17e4525cb3.tar.gz
chromium_src-345a8b7973e6693d115d20573f7cef17e4525cb3.tar.bz2
Remove the enable-sync flag from the Chrome command line and enable sync by default.
BUG=none Test=Sync my bookmarks should be enabled by default. Review URL: http://codereview.chromium.org/248024 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@27472 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/common')
-rw-r--r--chrome/common/chrome_switches.cc4
-rw-r--r--chrome/common/chrome_switches.h2
2 files changed, 3 insertions, 3 deletions
diff --git a/chrome/common/chrome_switches.h b/chrome/common/chrome_switches.h
index 3696066..79b185e 100644
--- a/chrome/common/chrome_switches.h
+++ b/chrome/common/chrome_switches.h
@@ -142,7 +142,7 @@ extern const wchar_t kGearsPluginPathOverride[];
extern const wchar_t kEnableFastback[];
-extern const wchar_t kEnableSync[];
+extern const wchar_t kDisableSync[];
extern const wchar_t kSyncerThreadTimedStop[];
extern const wchar_t kSyncerThreadPthreads[];
diff --git a/chrome/common/chrome_switches.cc b/chrome/common/chrome_switches.cc
index e79f345..72d6a5f 100644
--- a/chrome/common/chrome_switches.cc
+++ b/chrome/common/chrome_switches.cc
@@ -381,8 +381,8 @@ const wchar_t kGearsPluginPathOverride[] = L"gears-plugin-path";
// Enable the fastback page cache.
const wchar_t kEnableFastback[] = L"enable-fastback";
-// Enable syncing bookmarks to a Google Account.
-const wchar_t kEnableSync[] = L"enable-sync";
+// Disable syncing bookmarks to a Google Account.
+const wchar_t kDisableSync[] = L"disable-sync";
// Use the SyncerThread implementation that matches up with the old pthread
// impl semantics, but using Chrome synchronization primitives. The only